@@ -1,10 +1,10 @@
 import abc
-from typing import Union
+from typing import Dict, Union
 
 from .. import TokenBucket
 
 
-class BucketStorage(dict, metaclass=abc.ABCMeta):
+class BucketStorage(Dict, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def get_bucket(
         self, identifier: str, bucket_key: str
@@ -14,7 +14,7 @@ class BucketStorage(dict, metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def get_all_buckets(
         self, identifier: str
-    ) -> Union[dict[str, TokenBucket], None]:  # pragma: no cover
+    ) -> Union[Dict[str, TokenBucket], None]:  # pragma: no cover
         raise NotImplementedError()
 
     @abc.abstractmethod
