@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Dict
 
 
 class ThrottlerConfig:
@@ -6,7 +6,7 @@ class ThrottlerConfig:
     IDENTIFIER_FAIL_SAFE: bool = False
 
     @classmethod
-    def _configure(cls, config: dict) -> None:
+    def _configure(cls, config: Dict) -> None:
         for key, value in config.items():
             if not hasattr(cls, key):
                 return
@@ -16,8 +16,8 @@ class ThrottlerConfig:
             setattr(cls, key, value)
 
     @classmethod
-    def set(cls, config: dict = None) -> None:
-        if config and isinstance(config, dict):
+    def set(cls, config: Dict = None) -> None:
+        if config and isinstance(config, Dict):
             cls._configure(config)
             return
         raise TypeError(
