@@ -1,6 +1,6 @@
 import asyncio
 from threading import Lock
-from typing import Any, Callable, Union
+from typing import Any, Callable, Dict, List, Union
 
 from . import ThrottlerConfig, TokenBucket, TokenThrottlerException
 from .storage import BucketStorage
@@ -32,7 +32,7 @@ class TokenThrottler:
         validate_bucket_key(bucket_key)
         return self._buckets.get_bucket(identifier, bucket_key)
 
-    def get_all_buckets(self, identifier: str) -> Union[dict[str, TokenBucket], None]:
+    def get_all_buckets(self, identifier: str) -> Union[Dict[str, TokenBucket], None]:
         validate_identifier(identifier)
         return self._buckets.get_all_buckets(identifier)
 
@@ -55,7 +55,7 @@ class TokenThrottler:
     def add_from_dict(
         self,
         identifier: str,
-        bucket_config: list[dict[str, Any]],
+        bucket_config: List[Dict[str, Any]],
         remove_old_buckets: bool = False,
     ) -> None:
         validate_bucket_config(bucket_config, TokenBucket)
